Installation — pyRFtk 2.0.0 documentation

# Installation

## Pip

The program has a pre-build version which can be installed using pip, as this program is not yet made available in the python database, to install the program you’ll have to first clone the repository:

    git clone https://github.com/LPP-ERM-KMS/pyRFtk.git

Then navigate to the folder “dist” where the install file is located, and run

    (.venv) $pip install pyrftk2-2.0.0-py3-none-any.whl

which installs the program

## Source

If you’re planning to modify the source code to contribute to the project (or for your own benefit) you’ll have to clone the project to an easily accessible folder and add the path of the folder with the relative adress pyrftk/src/pyRFtk to you PYTHONPATH, e.g by adding the following to your .zshrc:

    export PYTHONPATH="${PYTHONPATH}:/path/to/pyrftk/src/pyRFtk"

## Dependencies

The software is dependent on numpy, scipy and matplotlib